\name{matrixT}
\alias{matrixT}
\alias{matrixVar}
\alias{matrixMean}

\title{ Multiple T Tests by Matrix Multiplication }
\description{
  Utility functions for computing vectors of row-by-row means,
  variances, and t-statistics.
}
\usage{
matrixMean(x)
matrixVar(x, xmean)
matrixT(m, v)
}
\arguments{
  \item{x}{ a matrix }
  \item{xmean}{ a numeric vector or single-column matrix }
  \item{m}{ a matrix }
  \item{v}{ a logical vector of length eual to the number of columns of \code{m} }
}
\value{
  \code{matrixMean} returns a single-column matrix containing the
  row-by-row means of \code{x}.

  \code{matrixVar} returns a signle-column matrix containing the
  row-by-row means of \code{x}, assuming that \code{xmean} contains the
  corresponding mean values.

  \code{matrixT} returns a single-column matrix of t-statistics from a
  two-sample t-test comparing the columns for which \code{v} is true to
  those for which \code{v} is false.
}

\author{Kevin R. Coombes <kcoombes@mdanderson.org>}
\seealso{ \code{\link{MultiTtest}} }
\examples{
ng <- 1000
ns <- 50
dat <- matrix(rnorm(ng*ns), ncol=ns)
clas <- factor(rep(c('Good', 'Bad'), each=25))
myMean <- matrixMean(dat)
myVar  <- matrixVar(dat, myMean)
plot(myMean, myVar)


myT <- matrixT(dat, clas)
hist(myT)

rm(ng, ns, dat, myMean, myVar, myT)
}
\keyword{array}
\keyword{htest}
\keyword{multivariate}
